danish
======


.. image:: https://codecov.io/gh/jmeyers314/danish/branch/main/graph/badge.svg?token=MW3K14XI9T
:target: https://codecov.io/gh/jmeyers314/danish

Geometric donut engine

Based on

Janish, R.,  "An algorithm for rapid measurement of aberrations in pairs of out-of-focus images", 2012, MIT undergraduate thesis.  https://dspace.mit.edu/handle/1721.1/78543
